miutil
======

Medical imaging utilities.

|Versions| |Py-Versions| |Tests| |LICENCE|

Basic functionality needed for `AMYPAD <https://github.com/AMYPAD/AMYPAD>`_
and `NiftyPET <https://github.com/NiftyPET/NiftyPET>`_.


Install
-------

Intended for inclusion in requirements for other packages.
The package name is ``miutil``. Options include:

- nii
- plot

To install options and their dependencies,
use the package name ``miutil[option1,option2]``.


.. |Tests| image:: https://img.shields.io/github/workflow/status/AMYPAD/miutil/Test
   :target: https://github.com/AMYPAD/miutil/actions
.. |Versions| image:: https://img.shields.io/pypi/v/miutil.svg
   :target: https://github.com/AMYPAD/miutil/releases
.. |Py-Versions| image:: https://img.shields.io/pypi/pyversions/miutil.svg?logo=python&logoColor=white
   :target: https://pypi.org/project/miutil
.. |LICENCE| image:: https://img.shields.io/pypi/l/miutil.svg
   :target: https://raw.githubusercontent.com/AMYPAD/miutil/master/LICENCE.md
